#!/bin/sh
#######################################################################
#
# Description:  This script is for finishing the installation of IM4T
#               once ASE has been installed.
# Usage:  im4tinst.sh [SAI_ROOT]
#         if SAI_ROOT is not passed in, it must be set in the environment
#
#######################################################################


IMUSER="imoadm"                  #IM4T administrative userid/group
TESTFILE="/tmp/im4tinst.tmp"   #temporary file (for storing err msgs)
TEST_MODE=false

#######################################################################
#Set some variables based on platform
#######################################################################
SYSTYPE=`uname -s`             #OS name
    case "$SYSTYPE"
    in

        "AIX")
          APPROOT=/usr
          ASEROOT=/aixase
            ;;
        "SunOS")
          APPROOT=/opt
          ASEROOT=/solarisase
            ;;
    esac


#######################################################################
#Verify the user has root priv
#######################################################################
IMID=`whoami`
if [ $IMID != root ]
then
  echo ERROR:  You must be root to run this script successfully.
  echo         Exiting.

  #This code enters a test mode if userid == amnuxoll
  if [ $IMID = amnuxoll ]
  then
    echo Userid is amnuxoll.  Entering test mode instead of exiting.
    TEST_MODE=true
    IMUSER=testuser
    IM4T_ROOT=/saiusers/home/amnuxoll/test
    SAI_ROOT=/build/team_ase/amnuxoll/tivtsd
  else
    exit
  fi
fi
  
#######################################################################
# Function Name: FindOrCreate
#   Description: Given a directory path, this function either creates
#                it or verifies that it exists
#######################################################################


FindOrCreate ()
{
if [ -d "$FCDIR" ]
then
  :
else
  /bin/mkdir $FCDIR  2> /dev/null
fi
}    

########################################################################
# Establish the location of SAI_ROOT
########################################################################

if [ $# -eq 0 ]
then
  if [ -z "$SAI_ROOT" ]
  then
    echo ERROR:  SAI_ROOT must be set or passed in as the first
    echo         argument to this shell script.
  fi
elif [ $# -eq 1 ]
then
  SAI_ROOT=$1
else
  echo "Usage:  $0 [SAI_ROOT]"
  exit
fi

########################################################################
#Do a spot check to see if the expected files are where they should be
########################################################################

if [ -d "${SAI_ROOT}${ASEROOT}/bin" ]
then
  :
else
  echo "ERROR:  A valid ASE install was not found in SAI_ROOT ($SAI_ROOT)"
  exit 1
fi

if [ -f "${SAI_ROOT}${ASEROOT}/lib/imtiface" ]
then
  :
else
  echo "ERROR:  IM4T support was not installed with the ASE install"
  echo "        found in SAI_ROOT ($SAI_ROOT)"
  exit 1
fi



echo Installing IM4T files from $SAI_ROOT

########################################################################
#if ${APPROOT}/TextTools already exists, prompt the user before proceeding
########################################################################

if [ -d ${IM4T_ROOT}${APPROOT}/TextTools/bin ]
then
  echo "ARE YOU SURE?  IM4T already appears to be installed on this"
  echo "system.  Executing this script will overwrite any files in"
  echo "the existing install."
  echo "Do you want to continue (y/n)? \c"
  IMANSWER="n"
  read IMANSWER
  if [ $IMANSWER = y -o $IMANSWER = yes ]
  then
    #Unset privs on all files that may be overwritten
    set +e
    /bin/chmod -R 755 ${IM4T_ROOT}${APPROOT}/TextTools/*
#    /bin/find ${IM4T_ROOT}${APPROOT}/TextTools -exec /bin/chmod u+w {} \; 2> /dev/null
    set -e
  else
    echo Exiting the script.
    exit 1
  fi
fi

#######################################################################
echo Building the expected directory tree
#######################################################################

FCDIR=${IM4T_ROOT}${APPROOT}
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/bin
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/lib
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/nls
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/nls/C
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US
FindOrCreate;
FCDIR=${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US
FindOrCreate;


#######################################################################
echo Creating the $IMUSER user and group
#######################################################################

if [ $TEST_MODE != true ]
then
  case "$SYSTYPE"
    in

        "AIX")
            # Use mkuser and mkgroup
	    set +e
            mkgroup $IMUSER 2>/dev/null
            rm $TESTFILE 2>/dev/null
            mkuser groups=$IMUSER home=/usr/TextTools $IMUSER 2>$TESTFILE
	    set -e
            if [ -s "$TESTFILE" ] 
            then
                cat $TESTFILE
            else
                echo "Set the $IMUSER password:"
                passwd $IMUSER
            fi
            ;;
        "SunOS")
            # Use useradd
	    set +e
            rm $TESTFILE 2>/dev/null
            useradd -c "Intelligent Miner for Text" -d ${APPROOT}/TextTools $IMUSER 2> $TESTFILE
	    set -e
            if [ -s $TESTFILE ]
            then
                cat $TESTFILE
            else
                echo "Set the $IMUSER password:"
                passwd $IMUSER
            fi
            ;;
    esac
fi


#######################################################################
echo Copying IM4T library files
#######################################################################

IM4TLIB=${IM4T_ROOT}${APPROOT}/TextTools/lib

/bin/cp ${SAI_ROOT}${ASEROOT}/lib/imtiface       $IM4TLIB

case "$SYSTYPE"
  in
    "AIX")
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imocxloc      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imocxtcp      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imolscfs      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imolssfs      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libibmcls.a   $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimo.a      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimoapi.a   $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimocs.a    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimofm.a    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimog.a     $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimogt.a    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimort.a    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimotm.a    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libitxco231.a $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libitxnl26x.a $IM4TLIB
      ;;
  "SunOS")
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/eflnl26s.a     $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imocxloc       $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imocxtcp       $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imogtb32.a     $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imogtc32.a     $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imogth32.so    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imolscfs       $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/imolssfs       $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libibmcl.so.1  $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimo.so      $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimoapi.so   $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimocs.so    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimofm.so    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimog.so     $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimogt.so    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libimotm.so    $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libitxco231.so $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libtask.so.1   $IM4TLIB
      /bin/cp ${SAI_ROOT}${ASEROOT}/lib/libxlC.so.1    $IM4TLIB
      ;;
esac
          
#######################################################################
echo Copying IM4T executable files
#######################################################################
IM4TBIN=${IM4T_ROOT}${APPROOT}/TextTools/bin

/bin/cp ${SAI_ROOT}${ASEROOT}/bin/imthelp310 $IM4TBIN/imthelp

case "$SYSTYPE"
  in
  "AIX")
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoappex $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocfgcl $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocfgsv $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoclrix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrcl  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrins $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrix  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrmt  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocsclt $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocssrv $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoctrix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imodelix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imolstix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imomsgix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoqueue $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoreoix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imorulix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosmbck $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosmdem $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosrch  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoss    $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imostaix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imostfix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imothesc $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imothesn $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imotrace $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoupdix $IM4TBIN
    ;;
  "SunOS")
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoappex $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocfgcl $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocfgsv $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoclrix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrcl  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrins $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrix  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocrmt  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocsclt $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imocssrv $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoctrix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imodelix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imolstix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imomsgix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoqueue $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoreoix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imorulix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosmbck $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosmdem $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imosrch  $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoss    $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imostaix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imostfix $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imothesc $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imothesn $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imotrace $IM4TBIN
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imoupdix $IM4TBIN
    ;;
esac

#######################################################################
echo Copying IM4T NLS and cfg files
#######################################################################

#These are on both platforms
/bin/cp ${SAI_ROOT}${ASEROOT}/bin/nodelock     ${IM4T_ROOT}${APPROOT}/TextTools
/bin/cp ${SAI_ROOT}${ASEROOT}/bin/imo.cat      ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US
/bin/cp ${SAI_ROOT}${ASEROOT}/bin/itxms231.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US

case "$SYSTYPE"
  in
  "AIX")
    ;;
  "SunOS")
    /bin/cp ${SAI_ROOT}${ASEROOT}/bin/imzmsg.cat   ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US
    ;;
esac

#######################################################################
echo Creating symbolic links
#######################################################################

case "$SYSTYPE"
  in
    "AIX")
      set +e
      /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcls 2> /dev/null
      /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface.a 2> /dev/null
      set -e
      /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcls.a ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcls
      /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface.a
      ;;
  "SunOS")
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcl.so
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcl.so.1 ${IM4T_ROOT}${APPROOT}/TextTools/lib/libibmcl.so
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/libtask.so
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/libtask.so.1 ${IM4T_ROOT}${APPROOT}/TextTools/lib/libtask.so
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/libxlC.so
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/libxlC.so.1 ${IM4T_ROOT}${APPROOT}/TextTools/lib/libxlC.so
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface.so
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface ${IM4T_ROOT}${APPROOT}/TextTools/lib/imtiface.so
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/imzmsg.cat
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/imzmsg.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/imzmsg.cat
    /bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/imzmsg.cat
    /bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/imzmsg.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/imzmsg.cat
    ;;
esac

#These are on both platforms
/bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/imo.cat
/bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/imo.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/imo.cat
/bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/itxms231.cat
/bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/itxms231.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/en_US/itxms231.cat
/bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/imo.cat
/bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/imo.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/imo.cat
/bin/rm -f  ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/itxms231.cat
/bin/ln -fs ${IM4T_ROOT}${APPROOT}/TextTools/nls/En_US/itxms231.cat ${IM4T_ROOT}${APPROOT}/TextTools/nls/C/itxms231.cat

#######################################################################
echo chown all files to $IMUSER:$IMUSER
#######################################################################

if [ $TEST_MODE != true ]
then
  /bin/chown -R ${IMUSER}:${IMUSER} ${IM4T_ROOT}${APPROOT}/TextTools/*
  /bin/chmod -R 755 ${IM4T_ROOT}${APPROOT}/TextTools/*
  /bin/chmod -R 777 ${SAI_ROOT}/CFG
fi

echo SUCCESS:  Installation Complete.
